import { Component, Input, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { LangChangeEvent, TranslateService } from '@ngx-translate/core';
import { MenuItem } from 'primeng/api';
import { AuthRoles } from 'src/app/models/auth/auth-roles.enum';
import { AuthService } from 'src/app/services/auth/auth.service';

@Component({
  selector: 'app-sidebar',
  templateUrl: './sidebar.component.html',
  styleUrls: ['./sidebar.component.scss']
})
export class SidebarComponent implements OnInit, OnChanges {

  @Input() isSidebarOpen: boolean;

  menuItems: MenuItem[];

  constructor(
    private authService: AuthService,
    private translateService: TranslateService
  ) { }

  ngOnInit(): void {
    this.translateService.onLangChange.subscribe(async (event: LangChangeEvent) => {
      await this.setMenu(this.isSidebarOpen);
    });
  }

  async setMenu(isSidebarOpen: boolean) {
    this.menuItems = [];
    this.menuItems = [
      { label: isSidebarOpen ? this.translateService.instant('sidebar.home') : '', icon: 'pi pi-home', routerLink: 'home' },
    ];

    if (await this.authService.hasUserPermission(AuthRoles.User) && !await this.authService.hasUserPermission(AuthRoles.Admin)) {
      this.menuItems.push(
        { label: isSidebarOpen ? this.translateService.instant('sidebar.gameserver') : '', icon: 'pi pi-desktop', routerLink: 'gameserver' },
      );
    }

    if (await this.authService.hasUserPermission(AuthRoles.Supporter) && !await this.authService.hasUserPermission(AuthRoles.Admin)) {
      this.menuItems.push(
        { label: isSidebarOpen ? this.translateService.instant('sidebar.support') : '', icon: 'pi pi-ticket', routerLink: 'support' },
      );
    }

    if (await this.authService.hasUserPermission(AuthRoles.Admin)) {
      this.menuItems.push(
        { label: isSidebarOpen ? this.translateService.instant('sidebar.host') : '', icon: 'pi pi-sitemap', routerLink: 'host' },
        { label: isSidebarOpen ? this.translateService.instant('sidebar.gameserver') : '', icon: 'pi pi-desktop', routerLink: 'gameserver' },
        { label: isSidebarOpen ? this.translateService.instant('sidebar.support') : '', icon: 'pi pi-ticket', routerLink: 'support' },
        { separator: true },
        { label: isSidebarOpen ? this.translateService.instant('sidebar.config') : '', icon: 'pi pi-cog', routerLink: '/admin/settings' },
        { label: isSidebarOpen ? this.translateService.instant('sidebar.auth_user_list') : '', icon: 'pi pi-user-edit', routerLink: '/admin/users' },
      );
    }
    this.menuItems = this.menuItems.slice();
  }

  async ngOnChanges(changes: SimpleChanges): Promise<void> {
    if (!changes)
      return;

    await this.setMenu(changes.isSidebarOpen.currentValue);
  }

}
