import { Injectable } from '@angular/core';
import * as signalR from "@aspnet/signalr";
import { ToastOptions } from 'src/app/models/utils/toast-options';
import { SettingsService } from '../settings/settings.service';
import { SpinnerService } from '../spinner/spinner.service';
import { ToastService } from '../toast/toast.service';

@Injectable({
  providedIn: 'root'
})
export class SignalRService {

  hubConnection: signalR.HubConnection;

  constructor(
    private settingsService: SettingsService,
    private toastService: ToastService,
    private spinnerService: SpinnerService
  ) { }

  startSignalR() {
    this.hubConnection = new signalR.HubConnectionBuilder()
      .configureLogging(signalR.LogLevel.Information)
      .withUrl(this.settingsService.getApiURL() + '/notify')
      .build();

    this.hubConnection.start().then(() => {
      console.log('Connected!');
    }).catch((err) => {
      const options: ToastOptions = {
        sticky: true,
        closable: false
      };
      this.spinnerService.showSpinner();
      this.toastService.error("Server nicht erreichbar", "Die Verbindung zum Server konnte nicht hergestellt werden!\nLaden Sie die Seite neu.", options);
      return console.error(err.toString());
    });

    this.hubConnection.onreconnected(() => {
      if (this.spinnerService.showSpinnerState) {
        this.spinnerService.hideSpinner();
        const options: ToastOptions = {
          closable: false
        };
        this.toastService.info("Server verbunden", "Die Verbindung zum Server konnte hergestellt werden.", options);
      }
    });

    this.hubConnection.onclose(() => {
      console.log('Disconnected');
      const options: ToastOptions = {
        sticky: true,
        closable: false
      };
      this.spinnerService.showSpinner();
      this.toastService.error("Server nicht erreichbar", "Die Verbindung zum Server konnte nicht hergestellt werden!\nLaden Sie die Seite neu.", options);
    });
  }
}
