import { Injectable } from '@angular/core';
import { Themes } from 'src/app/models/view/themes.enum';
import { AuthService } from '../auth/auth.service';

@Injectable({
  providedIn: 'root'
})
export class ThemeService {

  themeName: string;

  sidebarWidth = '150px';
  isSidebarOpen = false;
  hasLangChanged = false;

  constructor(
    private authService: AuthService
  ) {
    this.loadTheme();
    this.loadMenu();
  }

  loadTheme(): void {
    const token = this.authService.getDecodedToken();
    const mail = this.authService.getEMailFromDecodedToken(token);

    if (!mail) {
      this.themeName = localStorage.getItem(`default_themeName`);
      return;
    }

    let themeName = localStorage.getItem(`${mail}_themeName`);
    if (!themeName) {
      themeName = Themes.DefaultLight;
      this.setTheme(themeName);
    }
    this.themeName = themeName;
  }

  setTheme(name: string): void {
    this.authService.isUserLoggedInAsync().then(result => {
      if (!result) {
        localStorage.setItem(`default_themeName`, Themes.DefaultLight);
        this.themeName = Themes.DefaultLight;
      }

      const token = this.authService.getDecodedToken();
      const mail = this.authService.getEMailFromDecodedToken(token);
      localStorage.setItem(`${mail}_themeName`, name);
      localStorage.setItem(`default_themeName`, name);
      this.themeName = name;
    });
  }

  loadMenu() {
    const token = this.authService.getDecodedToken();
    const mail = this.authService.getEMailFromDecodedToken(token);

    if (!mail) {
      this.setSideWidth(true);
      return;
    }

    let isMenuOpen = true;
    let isMenuOpenStr = localStorage.getItem(`${mail}_isMenuOpen`);

    if (isMenuOpenStr != null || isMenuOpenStr != "") {
      isMenuOpen = Boolean(JSON.parse(isMenuOpenStr));
    }

    this.setIsMenuOpen(isMenuOpen);
  }

  setIsMenuOpen(isMenuOpen: boolean) {
    this.authService.isUserLoggedInAsync().then(result => {
      if (!result) {
        this.setSideWidth(true);
        return;
      }

      const token = this.authService.getDecodedToken();
      const mail = this.authService.getEMailFromDecodedToken(token);
      localStorage.setItem(`${mail}_isMenuOpen`, isMenuOpen + "");
      this.setSideWidth(isMenuOpen);
    });
  }

  setSideWidth($event): void {
    this.sidebarWidth = $event ? '150px' : '50px';
    this.isSidebarOpen = $event;
  }
}
